@@ -1,17 +1,18 @@
 # CRAN win-devel does not play well with fancy unicode x
-skip_on_cran()
-skip_if_not_installed("fixest")
+# Windows tests neither, but it works interactively
+# skip_on_cran()
+# skip_on_os("window")
 requiet("fixest")
 
 test_that(": in interactions become x", {
   mod <- lm(am ~ drat * mpg * vs, mtcars)
-  expect_snapshot_output(modelsummary(mod, "markdown"))
+  expect_snapshot(modelsummary(mod, "markdown"))
 })
 
 test_that("fixest i() becomes =", {
   testthat::skip_if_not_installed("fixest")
   mod <- suppressMessages(feols(Ozone ~ Solar.R + i(Month), airquality))
-  expect_snapshot_output(modelsummary(mod, "markdown", gof_map = list()))
+  expect_snapshot(modelsummary(mod, "markdown", gof_map = list()))
 })
 
 test_that("conditional conversion of : to x", {
